@@ -10,11 +10,12 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
-"""Output formatters using prettytable.
-"""
+"""Output formatters using prettytable."""
+
+import os
+import sys
 
 import prettytable
-import os
 
 from cliff import utils
 from . import base
@@ -32,6 +33,14 @@ def _format_row(row):
     return new_row
 
 
+def _do_fit(fit_width):
+    if os.name == 'nt':
+        # NOTE(pas-ha) the isatty is not reliable enough on Windows,
+        # so do not try to auto-fit
+        return fit_width
+    return sys.stdout.isatty() or fit_width
+
+
 class TableFormatter(base.ListFormatter, base.SingleFormatter):
 
     ALIGNMENTS = {
@@ -39,10 +48,6 @@ class TableFormatter(base.ListFormatter, base.SingleFormatter):
         str: 'l',
         float: 'r',
     }
-    try:
-        ALIGNMENTS[unicode] = 'l'
-    except NameError:
-        pass
 
     def add_argument_group(self, parser):
         group = parser.add_argument_group('table formatter')
@@ -104,7 +109,7 @@ class TableFormatter(base.ListFormatter, base.SingleFormatter):
         # preference to wrapping columns smaller than 8 characters.
         min_width = 8
         self._assign_max_widths(
-            stdout, x, int(parsed_args.max_width), min_width,
+            x, int(parsed_args.max_width), min_width,
             parsed_args.fit_width)
 
         formatted = x.get_string()
@@ -129,7 +134,7 @@ class TableFormatter(base.ListFormatter, base.SingleFormatter):
         # the Field column readable.
         min_width = 16
         self._assign_max_widths(
-            stdout, x, int(parsed_args.max_width), min_width,
+            x, int(parsed_args.max_width), min_width,
             parsed_args.fit_width)
 
         formatted = x.get_string()
@@ -174,17 +179,18 @@ class TableFormatter(base.ListFormatter, base.SingleFormatter):
         return shrink_fields, shrink_remaining
 
     @staticmethod
-    def _assign_max_widths(stdout, x, max_width, min_width=0, fit_width=False):
-        if min_width:
-            x.min_width = min_width
-
+    def _assign_max_widths(x, max_width, min_width=0, fit_width=False):
+        """Set maximum widths for columns of table `x`,
+        with the last column recieving either leftover columns
+        or `min_width`, depending on what offers more space.
+        """
         if max_width > 0:
             term_width = max_width
-        elif not fit_width:
+        elif not _do_fit(fit_width):
             # Fitting is disabled
             return
         else:
-            term_width = utils.terminal_width(stdout)
+            term_width = utils.terminal_width()
             if not term_width:
                 # not a tty, so do not set any max widths
                 return
@@ -211,6 +217,6 @@ class TableFormatter(base.ListFormatter, base.SingleFormatter):
             x.max_width[field] = max(min_width, shrink_to)
             shrink_remaining -= shrink_to
 
-        # give the last shrinkable column shrink_to plus any remaining
+        # give the last shrinkable column any remaining shrink or min_width
         field = shrink_fields[-1]
         x.max_width[field] = max(min_width, shrink_remaining)
